# Commands System

The extension registers the following core commands for quick access to various features.

- **View Category**
  - `monoco.openSettings`: Open extension configuration page.

- **Action Category**
  - `monoco.createIssue`: Open interactive interface to create new Issue.
  - `monoco.refreshEntry`: Force refresh Kanban data and action list.
